@@ -124,11 +124,7 @@ def from_pandas_dynamic(  # pylint: disable=too-many-arguments
 
     sm = StructureModel()
     sm.add_nodes_from(
-        [
-            "{var}_lag{l_val}".format(var=var, l_val=l_val)
-            for var in col_idx.keys()
-            for l_val in range(p + 1)
-        ]
+        [f"{var}_lag{l_val}" for var in col_idx.keys() for l_val in range(p + 1)]
     )
     sm.add_weighted_edges_from(
         [
@@ -156,7 +152,7 @@ def _format_name_from_pandas(idx_col: Dict[int, str], from_numpy_node: str) -> s
         nodes in from_pandas_dynamic format
     """
     idx, lag_val = from_numpy_node.split("_lag")
-    return "{var}_lag{l_val}".format(var=idx_col[int(idx)], l_val=lag_val)
+    return f"{idx_col[int(idx)]}_lag{lag_val}"
 
 
 def from_numpy_dynamic(  # pylint: disable=too-many-arguments
@@ -274,7 +270,7 @@ def _matrices_to_structure_model(
     """
     sm = StructureModel()
     lag_cols = [
-        "{var}_lag{l_val}".format(var=var, l_val=l_val)
+        f"{var}_lag{l_val}"
         for l_val in range(1 + (a_est.shape[0] // a_est.shape[1]))
         for var in range(a_est.shape[1])
     ]
@@ -318,12 +314,12 @@ def _reshape_wa(
     w_mat = w_plus - w_minus
     a_plus = (
         w_tilde[2 * d_vars :]
-        .reshape(2 * p_orders, d_vars ** 2)[::2]
+        .reshape(2 * p_orders, d_vars**2)[::2]
         .reshape(d_vars * p_orders, d_vars)
     )
     a_minus = (
         w_tilde[2 * d_vars :]
-        .reshape(2 * p_orders, d_vars ** 2)[1::2]
+        .reshape(2 * p_orders, d_vars**2)[1::2]
         .reshape(d_vars * p_orders, d_vars)
     )
     a_mat = a_plus - a_minus
@@ -426,8 +422,8 @@ def _learn_dynamic_structure(
             )
         )
         _h_value = _h(wa_vec)
-        l1_penalty = lambda_w * (wa_vec[: 2 * d_vars ** 2].sum()) + lambda_a * (
-            wa_vec[2 * d_vars ** 2 :].sum()
+        l1_penalty = lambda_w * (wa_vec[: 2 * d_vars**2].sum()) + lambda_a * (
+            wa_vec[2 * d_vars**2 :].sum()
         )
         return loss + 0.5 * rho * _h_value * _h_value + alpha * _h_value + l1_penalty
 
@@ -461,16 +457,16 @@ def _learn_dynamic_structure(
 
         grad_vec_w = np.append(
             obj_grad_w, -obj_grad_w, axis=0
-        ).flatten() + lambda_w * np.ones(2 * d_vars ** 2)
-        grad_vec_a = obj_grad_a.reshape(p_orders, d_vars ** 2)
+        ).flatten() + lambda_w * np.ones(2 * d_vars**2)
+        grad_vec_a = obj_grad_a.reshape(p_orders, d_vars**2)
         grad_vec_a = np.hstack(
             (grad_vec_a, -grad_vec_a)
-        ).flatten() + lambda_a * np.ones(2 * p_orders * d_vars ** 2)
+        ).flatten() + lambda_a * np.ones(2 * p_orders * d_vars**2)
         return np.append(grad_vec_w, grad_vec_a, axis=0)
 
     # initialise matrix, weights and constraints
-    wa_est = np.zeros(2 * (p_orders + 1) * d_vars ** 2)
-    wa_new = np.zeros(2 * (p_orders + 1) * d_vars ** 2)
+    wa_est = np.zeros(2 * (p_orders + 1) * d_vars**2)
+    wa_new = np.zeros(2 * (p_orders + 1) * d_vars**2)
     rho, alpha, h_value, h_new = 1.0, 0.0, np.inf, np.inf
 
     for n_iter in range(max_iter):
